%define srcname Vega-Strike-Engine-Source

# comment out if not pre rel
%define prel	alpha4

# rel for bumping
%define rel	2

%bcond_with ffmpeg

Name:		vegastrike
Version:	0.9.0
Release:	%mkrel %{?prel:0.%prel.}%{rel}
Summary:	3D OpenGL spaceflight simulator
License:	GPL-2.0-or-later
Group:		Games/Simulation
URL:		https://www.vega-strike.org/
Source0:	https://github.com/vegastrike/%{srcname}/archive/v%{version}%{?prel:-%prel}/%{srcname}-%{version}%{?prel:-%prel}.tar.gz
Source5:	vegastrike.png
Patch0:		vegastrike-add-mageia-distri-rpm-config.patch
# https://github.com/vegastrike/Vega-Strike-Engine-Source/pull/445
Patch1:		0001-cmake-Install-man-pages-into-matching-sub-directory.patch

BuildRequires:	cmake
BuildRequires:	boost-devel
%if %{with ffmpeg}
BuildRequires:	ffmpeg-devel
%endif
BuildRequires:	pkgconfig(expat)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(glut)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(opengl)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(zlib)

Requires:	xdg-utils
Requires:	%{name}-data >= %{version}
Recommends:	%{name}-sounds = %{version}

%description
Vega Strike is a GPL 3D OpenGL Action RPG space sim that
allows a player to trade and bounty hunt in the spirit
of Elite. You start in an old beat up Wayfarer
cargo ship, with endless possibility before you and just
enough cash to scrape together a life. Yet danger lurks in
the space beyond.

%prep
%autosetup -p1 -n %{srcname}-%{version}%{?prel:-%prel}

# Fix games bindir location
sed -i 's|DESTINATION bin|DESTINATION games|g' engine/CMakeLists.txt engine/setup/CMakeLists.txt engine/objconv/CMakeLists.txt

sed -i 's|Vega Strike Version: \${VEGASTRIKE_VERSION_LONG_STR}|Vega Strike Version: \${VEGASTRIKE_VERSION_LONG_STR}%{?prel:%prel}|' engine/CMakeLists.txt

%build
%global _vpath_srcdir engine
%cmake \
	-DDATADIR=%{_gamesdatadir}/%{name} \
	-DUSE_SYSTEM_BOOST:BOOL=ON \
	-DBUILD_STATIC_LIBS:BOOL=ON \
	-DBUILD_SHARED_LIBS:BOOL=OFF \
	-DENABLE_PIE:BOOL=ON \
	-DUSE_GTEST:BOOL=OFF \
	-DINSTALL_GTEST:BOOL=OFF \
	%{?with_ffmpeg:-DDISABLE_FFMPEG:BOOL=OFF}
%cmake_build

%install
%cmake_install

# We let RPM install it correctly itself
rm -rfv %{buildroot}%{_datadir}/doc/Vega_Strike

# icons and desktop are already provided upstream in vegastrike-data
%if 0
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Vega Strike
Comment=3D OpenGL spaceflight simulator
Comment[cs]=Hraj 3D vesmírnou simulaci
Comment[es]=Simulador de vuelo espacial 3D/OpenGL
GenericName=vegastrike
GenericName[en_US]=vegastrike
Exec=%{_gamesbindir}/vegastrike
Icon=%{name}
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
EOF

install -D -m0644 %{S:5} %{buildroot}%{_iconsdir}/hicolor/64x64/apps/%{name}.png
%endif

mkdir -p %{buildroot}%{_gamesdatadir}/%{name}

%files
%doc AUTHORS README.md
%license LICENSE
%{_gamesbindir}/vega*
%dir %{_gamesdatadir}/%{name}
%{_mandir}/man1/*


%changelog
* Wed Jun 19 2024 wally <wally> 0.9.0-0.alpha4.2.mga10
+ Revision: 2075403
- rebuild for boost 1.85.0

* Sun Apr 21 2024 daviddavid <daviddavid> 0.9.0-0.alpha4.1.mga10
+ Revision: 2060327
- new version: 0.9.0-alpha4

* Tue Feb 06 2024 daviddavid <daviddavid> 0.8.0-1.mga10
+ Revision: 2038125
- new version: 0.8.0
- switch to cmake build system
- revive vegastrike for mga10
+ wally <wally>
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x

* Tue Nov 13 2018 akien <akien> 0.5.1.r1-14.mga7
+ Revision: 1329833
- Remove OGRE dependency (don't build mesher tool)

* Thu Oct 18 2018 daviddavid <daviddavid> 0.5.1.r1-13.mga7
+ Revision: 1322074
- add patch to fix build on aarch64
+ wally <wally>
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 0.5.1.r1-12.mga7
+ Revision: 1301607
- Mageia 7 Mass Rebuild

* Sun May 13 2018 akien <akien> 0.5.1.r1-11.mga7
+ Revision: 1228838
- Rebuild for ogre 1.11.0

* Mon Dec 25 2017 wally <wally> 0.5.1.r1-10.mga7
+ Revision: 1184775
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 0.5.1.r1-9.mga7
+ Revision: 1178354
- rebuild for boost 1.65

* Mon Oct 09 2017 daviddavid <daviddavid> 0.5.1.r1-8.mga7
+ Revision: 1170480
- patch(3,4): fix build with gcc7
+ tv <tv>
- rebuild with latest boost

* Wed Feb 17 2016 umeabot <umeabot> 0.5.1.r1-7.mga6
+ Revision: 963191
- Mageia 6 Mass Rebuild

* Sun Dec 27 2015 barjac <barjac> 0.5.1.r1-6.mga6
+ Revision: 916110
- rebuild for boost-1.60.0

* Sat Sep 26 2015 daviddavid <daviddavid> 0.5.1.r1-5.mga6
+ Revision: 883873
- rebuild for new boost 1.59.0

* Fri Jul 31 2015 sander85 <sander85> 0.5.1.r1-4.mga6
+ Revision: 860140
- Rebuild for new boost

* Wed Oct 15 2014 umeabot <umeabot> 0.5.1.r1-3.mga5
+ Revision: 742176
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.5.1.r1-2.mga5
+ Revision: 690192
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Thu Mar 13 2014 dams <dams> 0.5.1.r1-1.mga5
+ Revision: 603199
- use better %%version

* Thu Mar 13 2014 dams <dams> 0.5.1-23.mga5
+ Revision: 603183
- remove useless icon as SOURCE11,12,13

* Sat Feb 08 2014 barjac <barjac> 0.5.1-22.mga5
+ Revision: 586801
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 0.5.1-21.mga4
+ Revision: 529298
- Mageia 4 Mass Rebuild

* Mon Jul 08 2013 fwang <fwang> 0.5.1-20.mga4
+ Revision: 451287
- rebuild for new boost

* Mon Jun 03 2013 fwang <fwang> 0.5.1-19.mga4
+ Revision: 436283
- fix build with recent libpng
- rebuild for new libpng

* Thu Apr 11 2013 barjac <barjac> 0.5.1-18.mga3
+ Revision: 409660
- rebuild for boost-1.53

* Tue Apr 02 2013 barjac <barjac> 0.5.1-17.mga3
+ Revision: 407090
- fix build for boost-1.53
- do not use rel for other than release or mass rebuild bot gets confused
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 malo <malo> 0.5.1-15.mga3
+ Revision: 343863
- add patch for automake-1.13
- updated RPM group
+ fwang <fwang>
- rebuild for new boost

* Tue Jul 31 2012 fwang <fwang> 0.5.1-13.mga3
+ Revision: 276859
- update install dir
- rebuild for new boost

* Sun Jul 01 2012 supp <supp> 0.5.1-12.mga3
+ Revision: 265952
- add -fpermissibe optflags as per ML recomendation to make it build
- update SPEC from beta->release
- update to final 0.5.1 release

* Wed May 30 2012 fwang <fwang> 0.5.1-11.mga3
+ Revision: 250032
- rebuild for new boost

* Sat Mar 03 2012 supp <supp> 0.5.1-10.mga2
+ Revision: 217645
- update to 0.5.1, Beta2

* Mon Nov 28 2011 fwang <fwang> 0.5.1-9.mga2
+ Revision: 173668
- rebuild for new boost

* Sun Sep 18 2011 fwang <fwang> 0.5.1-8.mga2
+ Revision: 145018
- it does not like latest ffmpeg
- br ffmpeg
- fix build with latest libpng
- rebuild for new libpng
- use freeglut
- more boost-mt fix
- link against boost-mt
- rebuild for new boost

* Sun May 15 2011 pterjan <pterjan> 0.5.1-6.mga1
+ Revision: 99038
- Rebuild for fixed find-requires

* Wed Apr 27 2011 wally <wally> 0.5.1-5.mga1
+ Revision: 92012
- use _real_vendor macro in desktop file name

* Tue Apr 26 2011 supp <supp> 0.5.1-4.mga1
+ Revision: 91785
- fix desktop file (mga#954)

* Sun Apr 03 2011 supp <supp> 0.5.1-3.mga1
+ Revision: 80032
- update to official 0.5.1 beta1 release, add suggests for speech+music

* Mon Feb 28 2011 supp <supp> 0.5.1-1.mga1
+ Revision: 61871
- update to 0.5.1 beta 1...
- imported package vegastrike


* Sat Nov 06 2010 Funda Wang <fwang@mandriva.org> 0.5.0-9mdv2011.0
+ Revision: 594144
- fix build with gcc 45
- rebuild for py 2.7

* Fri Feb 12 2010 Funda Wang <fwang@mandriva.org> 0.5.0-8mdv2010.1
+ Revision: 504922
- rebuild for new ogre

* Sat Jan 16 2010 Funda Wang <fwang@mandriva.org> 0.5.0-7mdv2010.1
+ Revision: 492263
- rebuild for new libjpegv8

* Thu Dec 31 2009 Tomas Kindl <supp@mandriva.org> 0.5.0-6mdv2010.1
+ Revision: 484456
- corrected mkrel
-fixed a typo in SPEC
-added patch for compiling under GCC 4.4.x
-rebuild for new OpenAL major
-This line, and following ones, will be ignored--
  file SPECS/vegastrike.spec modified

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Fri Apr 03 2009 Emmanuel Andry <eandry@mandriva.org> 0.5.0-5mdv2009.1
+ Revision: 363735
- oops, disable boost, really doesn't work
- fix menu group entry (#49371)

* Tue Mar 03 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.5.0-4mdv2009.1
+ Revision: 348029
- fix some format errors
- disabled -Werror=format-security, because of generated python bindings
- removed unused files

  + Funda Wang <fwang@mandriva.org>
    - rediff vssetup patch

* Sun Sep 07 2008 Emmanuel Andry <eandry@mandriva.org> 0.5.0-3mdv2009.0
+ Revision: 282390
- renumber patches
- spec cleanups
- add python patch from fedora
- disable boot

* Tue Aug 26 2008 Emmanuel Andry <eandry@mandriva.org> 0.5.0-2mdv2009.0
+ Revision: 276154
- rebuild for new ogre

* Sun Aug 24 2008 Emmanuel Andry <eandry@mandriva.org> 0.5.0-1mdv2009.0
+ Revision: 275568
- manually move binaries into gamesbindir, the makeinstall bindir=gamesbindir doesn't work
- move some binaries into libexecdir
- fix exec in desktop file
- update file list
- drop SOURCE2, setup is provided upstream
- rediff P11
- New version
- fix license
- BR ogre-devel
- drop patches 3 4 6 8 10 12 13
- rediff p5 9 14
- disable system boost, breaks build

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - rebuild

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Sat Dec 22 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 0.4.3-16mdv2008.1
+ Revision: 136765
- fix broken P13 to fix linking and failure to build

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Oct 26 2007 Crispin Boylan <crisb@mandriva.org> 0.4.3-15mdv2008.1
+ Revision: 102231
- Fix boost requires for x86_64
- Update patch 13 for new boost

* Thu Sep 06 2007 Emmanuel Andry <eandry@mandriva.org> 0.4.3-14mdv2008.0
+ Revision: 81358
- drop old menu

  + Thierry Vignaud <tv@mandriva.org>
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'


* Sun Feb 25 2007 Olivier Blin <oblin@mandriva.com> 0.4.3-13mdv2007.0
+ Revision: 125614
- more openal fixes
- fix openal support in configure
- buildrequire freealut-devel and oggvorbis-devel
- Import vegastrike

* Fri Sep 01 2006 David Walluck <walluck@mandriva.org> 0.4.3-12mdv2007.0
- BuildRequires: libboost-devel

* Sat Aug 26 2006 David Walluck <walluck@mandriva.org> 0.4.3-11mdv2007.0
- BuildRequires: libexpat-devel
- BuildRequires: X11-devel
- bunzip2 patches

* Fri Aug 25 2006 David Walluck <walluck@mandriva.org> 0.4.3-10mdv2007.0
- add xdg menu

* Wed Jun 14 2006 David Walluck <walluck@mandriva.org> 0.4.3-9mdv2007.0
- patch for gcc 4.1
- add vssetup and patch to build with %%{optflags} and gtk2-devel
- remove vegastrike.sh since it's already there as vsinstall
- clean tarball (remove *.a and src/boost*) and build with system boost
- change menu group to More Applications/Games/Arcade
- BuildRequires: mesaglu-devel

* Mon Mar 06 2006 Cris Boylan <misc@mandriva.org> 0.4.3-8mdk
- Build vslauncher with gtk2
- BuildRequires: gtk2-devel not gtk-devel

* Tue Feb 21 2006 David Walluck <walluck@mandriva.org> 0.4.3-7mdk
- BuildRequires: gtk-devel not gtk2-devel

* Tue Feb 14 2006 David Walluck <walluck@mandriva.org> 0.4.3-6mdk
- BuildRequires: gtk2-devel

* Mon Feb 13 2006 David Walluck <walluck@mandriva.org> 0.4.3-5mdk
- BuildRequires: SDL_mixer-devel

* Wed Feb 08 2006 David Walluck <walluck@mandriva.org> 0.4.3-4mdk
- fix build on x86_64
- fix wrong-file-end-of-line-encoding
- remove unused vssetup patch

* Sat Jul 09 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.4.3-3mdk
- fix build with gcc 4 (P8)
- fix ownership of datadir

* Sat May 07 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.4.3-2mdk
- lib64 fix
- %%mkrel

* Wed Feb 16 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.4.3-1mdk
- 0.4.3
- versioned requires
- update patches

* Tue Mar 02 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.4.1-2mdk
- force autoconf-2.5x
- fix buildrequires (lib64..)

